Data documentation compiled by Great Expectations

### titanic

### default

> > Titanic

####

##### Expectation Suites

BasicDatasetProfiler

####

##### Batch Validations

2019-07-28T190217.919144Z-BasicDatasetProfiler

### random

### default

> > f1

####

##### Expectation Suites

BasicDatasetProfiler

####

##### Batch Validations

2019-07-28T190218.264417Z-BasicDatasetProfiler

> > f2

####

##### Expectation Suites

BasicDatasetProfiler

####

##### Batch Validations

2019-07-28T190218.264417Z-BasicDatasetProfiler

Documentation autogenerated using Great Expectations .

This is a beta feature! Expect changes in API, behavior, and design.